==> php54-owncloud-7.0.3.tgz: share/owncloud/apps/contacts/l10n/zh_CN.php <==
<?php $TRANSLATIONS = array(
"Contacts" => "联系人",
"Ok" => "好",
"Cancel" => "取消",
"Save" => "保存",
"Edit Addressbook" => "编辑地址簿",
"Starting file import" => "开始文件导入",
"Format selected: {format}" => "已选择格式：{format}",
"Automatic format detection" => "自动格式检测",
"An address book called {name} already exists" => "名为{name}的地址薄已存在",
"Failed adding address book: {error}" => "增加地址薄失败：{error}",
"Failed loading address books: {error}" => "加载地址薄失败：{error}",
"Indexing contacts" => "联系人索引中",
"Unrecoverable error loading address books: {msg}" => "加载地址薄时遇到无法恢复的错误：{msg}",
"Error." => "错误",
"Add to..." => "增加到",
"Remove from..." => "从…删除",
"Add group..." => "增加分组…",
"Invalid URL: \"{url}\"" => "无效URL:\"{url}\"",
"Invalid email: \"{url}\"" => "无效的电子邮件: \"{url}\"",
"Merge failed. Cannot find contact: {id}" => "合并失败。无法找到联系人：{id}",
"Merge failed." => "合并失败",
"Merge failed. Error saving contact." => "合并失败。保存联系人出错。",
"Select photo" => "选择图片",
"Network or server error. Please inform administrator." => "网络或服务器错误。请通知管理员。",
"Only images can be used as contact photos" => "只有图像才可用作联系人照片",
"Error adding to group." => "增加到组时出错。",
"Error removing from group." => "从组删除时出错。",
"Error setting {name} as favorite." => "无法将{name}设为喜欢。",
"Merge contacts" => "合并联系人",
"Add group" => "增加分组",
"OK" => "OK",
"Could not find contact: {id}" => "不能找到联系人: {id}",
"Edit profile picture" => "编辑配置图片",
"Crop photo" => "裁剪照片",
"Error parsing date: {date}" => "解析日期出错：{date}",
"# groups" => "#群组",
"Error parsing birthday {bday}" => "生日格式错误 {bday}",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "一些联系人已被标注为删除，但是尚未完成，请稍候。",
"Click to undo deletion of {num} contacts" => "点击以撤销删除这{num}个联系人",
"Cancelled deletion of {num} contacts" => "取消删除{num}个联系人 ",
"Add" => "增加",
"Contact is already in this group." => "联系人已经在此分组中。",
"Contacts are already in this group." => "联系人都已经在这个组中。",
"Couldn't get contact list." => "无法获取联系人列表。",
"Contact is not in this group." => "联系人不在此分组中。",
"Contacts are not in this group." => "联系人都不在此分组中。",
"Failed renaming group: {error}" => "重命名分组失败：{error}",
"You can drag groups to\narrange them as you like." => "您可以通过拖拽分组的方式来按您喜欢的方式摆放他们。",
"Failed adding group: {error}" => "增加分组失败：{error}",
"All" => "全部",
"Favorites" => "收藏",
"Shared by {owner}" => "由{owner}共享",
"Not grouped" => "未分组",
"Failed loading groups: {error}" => "加载分组失败:{error}",
"Please choose the addressbook" => "请选择地址簿",
"Import into..." => "导入至...",
"Error loading import template" => "加载导入模板出错",
"Import contacts" => "导入联系人",
"Import" => "导入",
"Importing..." => "导入中",
"Import done" => "导入完毕",
"Close" => "关闭",
"Failed loading photo: {error}" => "加载照片失败：{error}",
"You do not have permissions to see this contact" => "你没有权限查看此联系人",
"Contact not found" => "联系人未找到",
"You do not have permissions to see these contacts" => "您没有权限查看这些联系人",
"You do not have permissions add contacts to the address book" => "您没有权限增加联系人到此地址簿",
"The backend for this address book does not support adding contacts" => "此地址簿的后端不支持增加联系人",
"You do not have permissions to delete this contact" => "你没有权限删除此联系人",
"The backend for this address book does not support deleting contacts" => "此地址簿的后端不支持删除联系人",
"Unknown error" => "未知错误",
"Access denied" => "访问被拒绝",
"The backend for this address book does not support updating" => "此地址簿的后端不支持更新",
"You don't have permissions to delete the address book." => "您没有权限删除地址簿",
"Address book not found" => "地址簿未找到",
"You do not have permissions to update this contact" => "你没有权限更新此联系人",
"The backend for this contact does not support updating it" => "此地址簿的后端不支持更新它",
"Property not found" => "属性未找到",
" Missing IM parameter for: " => "这些缺少IM参数：",
"Unknown IM: " => "未知即时通讯服务：",
"{name}'s Birthday" => "{name} 的生日",
"Error creating address book" => "创建地址薄出错",
"You do not have permissions to delete the \"%s\" address book" => "你没有权限删除地址簿“%s”",
"Error deleting address book" => "删除地址薄出错",
"Error creating contact." => "创建联系人出错。",
"Error creating contact" => "创建联系人出错",
"Error deleting contact" => "删除联系人出错",
"Error retrieving contact" => "检索联系人出错",
"Error saving contact" => "保存联系人时出错",
"Error removing contact from other address book." => "从其他地址簿移除联系人出错。",
"Couldn't find contact." => "无法找到联系人。",
"Error merging into contact." => "合并到联系人出错。",
"Error saving contact to backend." => "保存联系人到后台出错。",
"Property name is not set." => "属性名称未设置。",
"Property checksum is not set." => "属性校验值未设置。",
"Information about vCard is incorrect. Please reload the page." => "vCard 的信息不正确。请重新加载页面。",
"Error updating contact" => "更新联系人错误。",
"Error saving contact to backend" => "保存联系人到后台出错。",
"No photo path was submitted." => "未提供照片路径。",
"Error getting PHOTO property." => "获取照片属性时出错。",
"Error saving contact." => "保存联系人时出错。",
"No group name given." => "未指定组名称。",
"Error adding group." => "增加分组错误。",
"No group name to rename from given." => "未指定分组名称。",
"No group name to rename to given." => "未指定重命名的分组名称。",
"Error renaming group." => "重命名分组错误。",
"Group ID missing from request." => "请求缺少分组ID。",
"Group name missing from request." => "请求中缺少分组名",
"Contact ID missing from request." => "请求缺少联系人ID。",
"No file was uploaded. Unknown error" => "没有文件被上传。未知错误",
"There is no error, the file uploaded with success" => "文件上传成功，没有错误发生",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "上传的文件长度超出了 php.ini 中 upload_max_filesize 的限制",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "上传的文件超过MAX_FILE_SIZE的指令是在HTML表单中中指定的",
"The uploaded file was only partially uploaded" => "已上传文件只上传了部分（不完整）",
"No file was uploaded" => "没有文件被上传",
"Missing a temporary folder" => "缺少临时目录",
"Failed to write to disk" => "写入磁盘失败",
"Not enough storage available" => "没有足够的存储空间",
"Attempt to upload blacklisted file:" => "尝试上传黑名单文件：",
"Error uploading contacts to storage." => "上传联系人到存储空间时出错",
"You do not have permissions to import into this address book." => "您没有权限导入到此地址簿。",
"File name missing from request." => "请求缺少文件名。",
"Progress key missing from request." => "请求缺少进度。",
"Attempt to access blacklisted file:" => "尝试访问黑名单文件：",
"No key is given." => "未指定键。",
"No value is given." => "未指定值。",
"Could not set preference: " => "无法设定偏好：",
"Contact" => "联系人",
"Other" => "其它",
"HomePage" => "主页",
"Jabber" => "Jabber",
"Internet call" => "网络呼叫",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "GoogleTalk",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"ownCloud" => "ownCloud",
"Work" => "工作",
"Home" => "家庭",
"Mobile" => "手机",
"Text" => "文本",
"Voice" => "语音",
"Message" => "消息",
"Fax" => "传真",
"Video" => "视频",
"Pager" => "传呼机",
"Internet" => "互联网",
"Friends" => "朋友",
"Family" => "家庭",
"Group name" => "组名称",
"Address books" => "地址簿",
"Display name" => "显示名称",
"Add Address Book" => "增加地址薄",
"Automatic format" => "自动格式",
"Select file..." => "选择文件...",
"(De-)select all" => "选择 (反选) 全部",
"Sort order" => "排序",
"First- Lastname" => "名- 姓",
"Last-, Firstname" => "姓-, 名",
"Delete" => "删除",
"Groups" => "组",
"Download" => "下载",
"Email" => "电子邮件",
"Phone" => "电话",
"Address" => "地址",
"Group" => "分组",
"Keyboard shortcuts" => "快捷键",
"Navigation" => "导航",
"Next contact in list" => "列表中的下一个联系人",
"Previous contact in list" => "列表中的上一个联系人",
"Expand/collapse current addressbook" => "展开/收起此地址簿",
"Next addressbook" => "下一个地址簿",
"Previous addressbook" => "上一个地址簿",
"Actions" => "地址",
"Refresh contacts list" => "刷新联系人列表",
"Add new contact" => "新增联系人",
"Add new addressbook" => "新增地址簿",
"Delete current contact" => "删除当前联系人",
"Which contact should the data be merged into?" => "要将数据合并到哪个联系人？",
"Delete the other(s) after successful merge?" => "在成功合并后删除其他项？",
"Compose mail" => "编写邮件",
"Delete current photo" => "删除当前照片",
"Edit current photo" => "编辑当前照片",
"Upload new photo" => "上传新照片",
"Favorite" => "收藏",
"Name" => "名称",
"First name" => "名",
"Additional names" => "其他名称",
"Last name" => "姓",
"Address book" => "地址簿",
"Nickname" => "昵称",
"Title" => "标题",
"Organization" => "组织",
"Birthday" => "生日",
"Website" => "网站",
"Notes go here..." => "注释放在这里...",
"Instant Messaging" => "即时通讯",
"Note" => "注释",
"Web site" => "网址",
"Preferred" => "偏好",
"Please specify a valid email address." => "请指定合法的电子邮件地址",
"someone@example.com" => "someone@example.com",
"Mail to address" => "发送邮件到地址",
"Delete email address" => "删除电子邮件地址",
"Enter phone number" => "输入电话号码",
"Go to web site" => "访问网址",
"View on map" => "在地图上显示",
"Street address" => "街道地址",
"Postal code" => "邮政编码",
"City" => "城市",
"State or province" => "州/省",
"Country" => "国家",
"Instant Messenger" => "即时通讯",
"Active" => "活动",
"Share" => "共享",
"Export" => "导出",
"CardDAV link" => "CardDAV 链接",
"Edit" => "编辑",
"Description" => "描述",
"User" => "用户",
"Password" => "密码",
"Base DN" => "Base DN"
);

==> php54-owncloud-8.0.3.tgz: share/owncloud/apps/contacts/l10n/zh_CN.php <==
<?php
$TRANSLATIONS = array(
"Contacts" => "联系人",
"Add new LDAP Addressbook" => "添加新 LDAP 地址簿",
"Ok" => "确定",
"Cancel" => "取消",
"Save" => "保存",
"Edit Addressbook" => "编辑地址簿",
"Import contacts" => "导入联系人",
"Upload file..." => "上传文件...",
"Starting file import" => "开始文件导入",
"Format selected: {format}" => "已选择格式：{format}",
"Automatic format detection" => "自动检测格式",
"Import into..." => "导入至...",
"Processing {count}/{total} cards" => "已从{total}个联系人导入{count}个",
"Total: {total}, Success: {imported}, Errors: {failed}" => "共计: {total}, 成功: {imported}, 错误: {failed}",
"An address book called {name} already exists" => "名为{name}的地址薄已存在",
"Failed adding address book: {error}" => "增加地址薄失败：{error}",
"Failed loading address books: {error}" => "加载地址薄失败：{error}",
"Server error! Please inform system administator" => "服务器错误。请通知管理员。",
"Indexing contacts" => "联系人索引中",
"Unrecoverable error loading address books: {msg}" => "加载地址薄时遇到无法恢复的错误：{msg}",
"Error." => "错误",
"Add to..." => "增加到...",
"Remove from..." => "删除自...",
"Add group..." => "增加群组...",
"Invalid URL: \"{url}\"" => "无效URL:\"{url}\"",
"Invalid email: \"{url}\"" => "无效的电子邮件: \"{url}\"",
"Merge failed. Cannot find contact: {id}" => "合并失败。无法找到联系人：{id}",
"Merge failed." => "合并失败.",
"Merge failed. Error saving contact." => "合并失败。保存联系人出错。",
"Select photo" => "选择图片",
"Network or server error. Please inform administrator." => "网络或服务器错误。请通知管理员。",
"Only images can be used as contact photos" => "只有图像才可用作联系人照片",
"The size of \"{filename}\" exceeds the maximum allowed {size}" => "{filename} 的文件大小超过了最大的 {size} 限制",
"Error adding to group." => "增加到群组时出错。",
"Error removing from group." => "从群组删除时出错。",
"You have selected over 300 contacts.\nThis will most likely fail! Click here to try anyway." => "您选择了超过 300 联系人.\n很可能会执行失败，点击这里继续尝试.",
"Error setting {name} as favorite." => "无法将{name}设为喜欢。",
"Merge contacts" => "合并联系人",
"Add group" => "增加分组",
"OK" => "确定",
"Could not find contact: {id}" => "找不到联系人: {id}",
"Edit profile picture" => "编辑配置图片",
"Crop photo" => "裁剪照片",
"Error parsing date: {date}" => "解析日期出错：{date}",
"# groups" => "#群组",
"Error parsing birthday {bday}" => "生日格式错误 {bday}",
"The backend does not support multi-byte characters." => "此后端不支持多字节字符。",
"Some contacts are marked for deletion, but not deleted yet. Please wait for them to be deleted." => "一些联系人已被标注为删除，但是尚未完成，请稍候。",
"Click to undo deletion of {num} contacts" => "点击以撤销删除这{num}个联系人",
"Cancelled deletion of {num} contacts" => "取消删除{num}个联系人 ",
"Add" => "增加",
"Contact is already in this group." => "联系人已经在此分组中。",
"Contacts are already in this group." => "联系人都已经在这个群组中。",
"Couldn't get contact list." => "无法获取联系人列表。",
"Contact is not in this group." => "联系人不在此分组中。",
"Contacts are not in this group." => "联系人都不在此分组中。",
"A group named \"{group}\" already exists" => "名为“{group}”的群组已经存在",
"Failed renaming group: {error}" => "重命名分组失败：{error}",
"Failed adding group: {error}" => "增加分组失败：{error}",
"All" => "全部",
"Favorites" => "收藏",
"Shared by {owner}" => "由{owner}共享",
"Not grouped" => "未分组",
"Failed loading groups: {error}" => "加载分组失败:{error}",
"Please choose the addressbook" => "请选择地址簿",
"Error loading import template" => "加载导入模板出错",
"Import" => "导入",
"Importing..." => "导入中...",
"Import done" => "导入完毕",
"Close" => "关闭",
"Contact" => "联系人",
"Error, missing parameters: " => "错误，缺失的参数：",
"Failed loading photo: {error}" => "加载照片失败：{error}",
"You do not have permissions to see this contact" => "你没有权限查看此联系人",
"Contact not found" => "联系人未找到",
"You do not have permissions to see these contacts" => "您没有权限查看这些联系人",
"You do not have permissions add contacts to the address book" => "您没有权限增加联系人到此地址簿",
"The backend for this address book does not support adding contacts" => "此地址簿的后端不支持增加联系人",
"You do not have permissions to delete this contact" => "你没有权限删除此联系人",
"The backend for this address book does not support deleting contacts" => "此地址簿的后端不支持删除联系人",
"Unknown error" => "未知错误",
"Access denied" => "访问被拒绝",
"The backend for this address book does not support updating" => "此地址簿的后端不支持更新",
"You don't have permissions to delete the address book." => "您没有权限删除地址簿",
"Address book not found" => "地址簿未找到",
"You do not have permissions to update this contact" => "你没有权限更新此联系人",
"The backend for this contact does not support updating it" => "此地址簿的后端不支持更新它",
"This backend does not support adding contacts" => "此后端不支持添加联系人",
"Property not found" => "属性未找到",
" Missing IM parameter for: " => "这些缺少IM参数：",
"Unknown IM: " => "未知即时通讯服务：",
"{name}'s Birthday" => "{name} 的生日",
"Error creating address book" => "创建地址薄出错",
"The \"%s\" backend does not support deleting address books" => "\"%s\" 后端不支持删除地址簿",
"You do not have permissions to delete the \"%s\" address book" => "你没有权限删除地址簿“%s”",
"Error deleting address book" => "删除地址薄出错",
"Error creating contact." => "创建联系人出错。",
"Error creating contact" => "创建联系人出错",
"Error deleting contact" => "删除联系人出错",
"Error retrieving contact" => "获取联系人出错",
"Error saving contact" => "保存联系人时出错",
"Error removing contact from other address book." => "从其他地址簿移除联系人出错。",
"Error getting moved contact" => "获取移动了的联系人出错",
"Couldn't find contact." => "无法找到联系人。",
"No contact data in request." => "请求中无联系人数据.",
"Error merging into contact." => "合并到联系人出错。",
"Error saving contact to backend." => "保存联系人到后台出错。",
"Property name is not set." => "属性名称未设置。",
"Property checksum is not set." => "属性校验值未设置。",
"Information about vCard is incorrect. Please reload the page." => "vCard 的信息不正确。请重新加载页面。",
"Error updating contact" => "更新联系人出错",
"Error saving contact to backend" => "保存联系人到后台出错",
"No photo path was submitted." => "未提供照片路径。",
"Error loading image from cache" => "从缓存中载入图像时出错",
"Error getting PHOTO property." => "获取照片属性时出错。",
"Error saving contact." => "保存联系人时出错。",
"No group name given." => "未指定组名称。",
"Error adding group." => "增加分组错误。",
"No group ID given." => "未给出群组 ID",
"No group name to rename from given." => "未指定分组名称。",
"No group name to rename to given." => "未指定重命名的分组名称。",
"Error renaming group." => "重命名分组错误。",
"Group ID missing from request." => "请求缺少分组ID。",
"Group name missing from request." => "请求中缺少分组名",
"Contact ID missing from request." => "请求缺少联系人ID。",
"No file was uploaded. Unknown error" => "没有文件被上传。未知错误",
"There is no error, the file uploaded with success" => "文件上传成功，没有错误发生",
"The uploaded file exceeds the upload_max_filesize directive in php.ini" => "上传的文件长度超出了 php.ini 中 upload_max_filesize 的限制",
"The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" => "上传的文件超过MAX_FILE_SIZE的指令是在HTML表单中中指定的",
"The uploaded file was only partially uploaded" => "已上传文件只上传了部分（不完整）",
"No file was uploaded" => "没有文件被上传",
"Missing a temporary folder" => "缺少临时目录",
"Failed to write to disk" => "写入磁盘失败",
"Not enough storage available" => "没有足够的存储空间",
"Attempt to upload blacklisted file:" => "尝试上传黑名单文件：",
"Error uploading contacts to storage." => "上传联系人到存储空间时出错",
"Error moving file to imports folder." => "无法将文件移动到导入文件夹.",
"You do not have permissions to import into this address book." => "您没有权限导入到此地址簿。",
"File name missing from request." => "请求缺少文件名。",
"Progress key missing from request." => "请求缺少进度。",
"Attempt to access blacklisted file:" => "尝试访问黑名单文件：",
"No key is given." => "未指定键。",
"No value is given." => "未指定值。",
"Could not set preference: " => "无法设定偏好：",
"Other" => "其它",
"HomePage" => "主页",
"Jabber" => "Jabber",
"Internet call" => "网络呼叫",
"AIM" => "AIM",
"MSN" => "MSN",
"Twitter" => "Twitter",
"GoogleTalk" => "GoogleTalk",
"Facebook" => "Facebook",
"XMPP" => "XMPP",
"ICQ" => "ICQ",
"Yahoo" => "Yahoo",
"Skype" => "Skype",
"QQ" => "QQ",
"GaduGadu" => "GaduGadu",
"ownCloud" => "ownCloud",
"Work" => "工作",
"Home" => "家庭",
"Mobile" => "手机",
"Text" => "文本",
"Voice" => "语音",
"Message" => "消息",
"Fax" => "传真",
"Video" => "视频",
"Pager" => "传呼机",
"Internet" => "互联网",
"Friends" => "朋友",
"Family" => "家庭",
"Enable LDAP Backend" => "启用 LDAP 后端",
"Enable LDAP backend for the contacts application" => "为联系人应用启用 LDAP 后端",
"Warning: LDAP Backend is in beta mode, use with precautions" => "警告：LDAP 后端尚在测试阶段，请在使用时注意",
"New contact" => "新建联系人",
"Group name" => "群组名称",
"New group" => "新建群组",
"Address books" => "地址簿",
"Display name" => "显示名称",
"Add Address Book" => "增加地址薄",
"Add LDAP Address Book" => "添加 LDAP 地址簿",
"(De-)select all" => "选择 (反选) 全部",
"Sort order" => "排序",
"First- Lastname" => "名- 姓",
"Last-, Firstname" => "姓-, 名",
"Delete" => "删除",
"Groups" => "群组",
"Download" => "下载",
"Merge" => "合并",
"Email" => "电子邮件",
"Phone" => "电话",
"Address" => "地址",
"Group" => "分组",
"Keyboard shortcuts" => "快捷键",
"Navigation" => "导航",
"Next contact in list" => "列表中的下一个联系人",
"Previous contact in list" => "列表中的上一个联系人",
"Expand/collapse current addressbook" => "展开/收起此地址簿",
"Next addressbook" => "下一个地址簿",
"Previous addressbook" => "上一个地址簿",
"Actions" => "动作",
"Refresh contacts list" => "刷新联系人列表",
"Add new contact" => "新增联系人",
"Add new addressbook" => "新增地址簿",
"Delete current contact" => "删除当前联系人",
"You have no contacts in your address book or your address book is disabled." => "地址簿中无联系人或地址簿已经禁用",
"Add a new contact or import existing contacts from a file (VCF, CSV or LDIF)." => "添加新联系人或者从文件(VCF, CSV 或 LDIF) 导入联系人.",
"Which contact should the data be merged into?" => "要将数据合并到哪个联系人？",
"Delete the other(s) after successful merge?" => "在成功合并后删除其他项？",
"Compose mail" => "编写邮件",
"Delete current photo" => "删除当前照片",
"Edit current photo" => "编辑当前照片",
"Upload new photo" => "上传新照片",
"Select photo from Files" => "从文件中选择照片",
"Favorite" => "收藏",
"Name" => "名称",
"First name" => "名",
"Additional names" => "其他名称",
"Last name" => "姓",
"Address book" => "地址簿",
"Nickname" => "昵称",
"Title" => "标题",
"Organization" => "组织",
"Birthday" => "生日",
"Website" => "网站",
"Instant messaging" => "即时通讯",
"Notes go here..." => "注释放在这里...",
"Add field..." => "增加字段...",
"Instant Messaging" => "即时通讯",
"Note" => "注释",
"Web site" => "网址",
"Preferred" => "偏好",
"Please specify a valid email address." => "请指定合法的电子邮件地址",
"someone@example.com" => "someone@example.com",
"Mail to address" => "发送邮件到地址",
"Delete email address" => "删除电子邮件地址",
"Enter phone number" => "输入电话号码",
"Go to web site" => "访问网址",
"View on map" => "在地图上显示",
"Street address" => "街道地址",
"Postal code" => "邮政编码",
"City" => "城市",
"State or province" => "州/省",
"Country" => "国家",
"Instant Messenger" => "即时通讯",
"Active" => "活动",
"Share" => "共享",
"Export" => "导出",
"CardDAV link" => "CardDAV 链接",
"Edit" => "编辑",
"Format" => "格式",
"Automatic format" => "自动格式",
"Select file..." => "选择文件...",
"Addressbook URI" => "地址簿 URI",
"URI" => "URI",
"Description" => "描述",
"LDAP URL" => "LDAP 地址",
"Anonymous" => "匿名",
"Read-only" => "只读",
"Read-Only" => "只读",
"User" => "用户",
"Password" => "密码",
"Page size" => "页面大小",
"Base DN for search" => "搜索的 Base DN",
"Base DN" => "Base DN",
"Search filter" => "搜索过滤器",
"Filter" => "过滤器",
"Base DN for modification" => "修改的 Base DN",
"Base DN modification" => "Base DN 修改",
"Connector" => "连接器",
"Copy from (Warning, replaces current custom value)" => "复制于(注意, 替换当前预设值)"
);
$PLURAL_FORMS = "nplurals=1; plural=0;";
